<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Versuchen</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Gefunden</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Groß</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Übersehen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Richtig</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Spiel beendet</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 von %n Punkt</numerusform>
            <numerusform>%1 von %n Punkten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 von %n Punkt</numerusform>
            <numerusform>3 von %n Punkten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 von %n Punkt</numerusform>
            <numerusform>2 von %n Punkten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 von %n Punkt</numerusform>
            <numerusform>1 von %n Punkten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 von %n Punkt</numerusform>
            <numerusform>0 von %n Punkten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n Punkt</numerusform>
            <numerusform>%n Punkte</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Der Maximalscore wurde anhand der folgenden 30 Wörter berechnet:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n Versuch</numerusform>
            <numerusform>%n Versuche</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n Fehler</numerusform>
            <numerusform>%n Fehler</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Klassisch</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Ausdauer</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Verlieren</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Festanzahl</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disziplin</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Zählt von 30 Sekunden abwärts und erhöht bei richtigen Versuchen.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Zählt von 3 Minuten abwärts.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Zählt von 30 Sekunden abwärts und setzt bei richtigen Versuchen zurück.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Zählt von 45 Sekunden abwärts und pausiert bei richtigen Versuchen.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Spiel endet nach 3 falschen Versuchen.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Spiel endet nach 30 Versuchen.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Zählt von 30 Sekunden abwärts und erhöht oder verringert bei Versuchen.</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Unbegrenzt</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation>Spiel endet, wenn alle Wörter gefunden sind.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Würfel konnte nicht aus Datei gelesen werden.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Wortliste konnte nicht aus Datei gelesen werden.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Spielfeldsprache</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Auswählen ...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Hinweis:&lt;/b&gt; Diese Einstellungen werden nach dem Start eines neuen Spiels aktiv.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Sprache:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Würfel:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Wortliste:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Wörterbuch:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Würfeldatei auswählen</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Wortlistendatei auswählen</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Anwendungssprache auswählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemeinstellung&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte Anwendung neu starten, um den Wechsel der Sprache auszuführen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Neues Spiel</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Anzahl Wörter:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Mindestwortlänge:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Zufällig</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n Buchstabe</numerusform>
            <numerusform>%n Buchstaben</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Highscores</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>%1.</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rang</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Glückwunsch!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Sie haben Ihren Highscore geschlagen!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Gut gemacht!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Sie haben einen neuen Highscore!</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>–</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Pausiert&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Zum Weiterspielen klicken.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Spiel wird geladen ...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Zum Start eines neuen Spiels klicken.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Neues Spielfeld wird generiert ...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Bitte warten&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Wortliste wird optimiert ...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Ne&amp;ues Spiel ...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Strg+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Neu würfeln</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>I&amp;mportieren ...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Exportieren ...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Spiel beenden</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausieren</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Strg+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Details</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Highscores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Strg+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>&amp;Maximale Punktzahl zeigen</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Spielende</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>I&amp;mmer</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Ü&amp;bersehene Wörter zeigen</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>&amp;Wörterzahlen zeigen</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>&amp;Spielfeldsprache ...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Anwendungssprache ...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Steuerung</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Ü&amp;ber</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Eine Einzelspielervariante von &lt;a href=&quot;http://de.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Englische Wortliste basiert auf &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; von Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Hebräische Wortliste basiert auf &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; von Nadav Har&apos;El und Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Spiel importieren</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Tanglet-Spiele (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Gewähltes Spiel konnte nicht gestartet werden.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Spiel exportieren</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Gegenwärtiges Spiel abbrechen?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Spielfeldgröße:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Groß</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Wörterdichte:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Wortlänge:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 oder mehr Buchstaben</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Spieltyp:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Steuerung</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mit der Maus:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wort auswählen:&lt;/b&gt; Auf die Buchstaben eines Worts klicken.&lt;br&gt;&lt;b&gt;Einen Versuch machen:&lt;/b&gt; Auf den zuletzt ausgewählten Buchstaben klicken.&lt;br&gt;&lt;b&gt;Buchstaben entfernen:&lt;/b&gt; Auf einen vorher ausgewählten Buchstaben klicken.&lt;br&gt;&lt;b&gt;Wort löschen:&lt;/b&gt; Zweimal auf den ersten ausgewählten Buchstaben klicken.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Mit der Tastatur:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wort auswählen:&lt;/b&gt; Die Buchstaben eines Worts tippen.&lt;br&gt;&lt;b&gt;Einen Versuch machen:&lt;/b&gt; Eingabetaste drücken.&lt;br&gt;&lt;b&gt;Wort löschen:&lt;/b&gt; Strg+Backspace drücken.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Strg+H</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Buchstaben:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Gefunden:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n Punkt</numerusform>
            <numerusform>%n Punkte</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Buchstabenrätsel</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Spieldatei zum Spielen.</translation>
    </message>
</context>
</TS>
